#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MFIVE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MFIVE_HPP_INCLUDED

#include <boost/simd/constant/include/constants/mfive.hpp>

#endif
